@@ -421,60 +421,21 @@ class BaseExperiment:
 
         elif isinstance(self.model, pl.LightningModule): # other lightning modules not in astrape
             batch_size = 256 if torch.cuda.is_available() else 64
-            if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
-                data_module = initialize_datamodule(
-                    batch_size=batch_size, 
-                    X=self.X, 
-                    y=self.y,
-                    X_val=self.X_val,
-                    y_val=self.y_val,
-                    X_test=self.X_test,
-                    y_test=self.y_test,
-                    test_size=self.test_size,
-                    random_state=self.random_state,
-                    stratify=self.stratify
-                )
-            elif self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
-                data_module = initialize_datamodule(
-                    batch_size=batch_size, 
-                    X=self.X, 
-                    y=self.y,
-                    X_val=self.X_val.reshape((self.X_val.shape[0], -1)),
-                    y_val=self.y_val,
-                    X_test=self.X_test,
-                    y_test=self.y_test,
-                    test_size=self.test_size,
-                    random_state=self.random_state,
-                    stratify=self.stratify
-                )
             
-            elif self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
-                data_module = initialize_datamodule(
-                    batch_size=batch_size, 
-                    X=self.X, 
-                    y=self.y,
-                    X_val=self.X_val,
-                    y_val=self.y_val,
-                    X_test=self.X_test.reshape((self.X_test.shape[0], -1)),
-                    y_test=self.y_test,
-                    test_size=self.test_size,
-                    random_state=self.random_state,
-                    stratify=self.stratify
-                )
-
-            elif self.X_val is not None and self.y_val is not None and self.X_test is not None and self.y_test is not None:
-                data_module = initialize_datamodule(
-                    batch_size=batch_size, 
-                    X=self.X, 
-                    y=self.y,
-                    X_val=self.X_val,
-                    y_val=self.y_val,
-                    X_test=self.X_test,
-                    y_test=self.y_test,
-                    test_size=self.test_size,
-                    random_state=self.random_state,
-                    stratify=self.stratify
-                )
+            data_module = initialize_datamodule(
+                batch_size=batch_size, 
+                X=self.X, 
+                y=self.y,
+                X_val=self.X_val.reshape(-1, *(self.X.shape[1:])),
+                y_val=self.y_val,
+                X_test=self.X_test.reshape(-1, *(self.X.shape[1:])),
+                y_test=self.y_test,
+                test_size=self.test_size,
+                random_state=self.random_state,
+                stratify=self.stratify
+            )
+            
+            
         elif isinstance(self.model, BaseEstimator):
             if self.X_test is None and self.y_test is None:
                 if self.n_classes is None:
